@@ -251,7 +251,7 @@ class security_manager {
         }
         
         // Store in local database
-        $unblock_time = $permanent ? 0 : (time() + $this->block_duration); // 0 means permanent/manual unblock only
+        $unblock_time = $permanent ? -1 : (time() + $this->block_duration); // -1 means permanent/manual unblock only
         $stmt = $this->db->prepare('INSERT OR REPLACE INTO blocked_ips (ip_address, block_time, unblock_time, reason, failed_attempts, manual_block) VALUES (:ip, :block_time, :unblock_time, :reason, :attempts, :manual)');
         $stmt->bindValue(':ip', $ip_address, SQLITE3_TEXT);
         $stmt->bindValue(':block_time', time(), SQLITE3_INTEGER);
@@ -331,14 +331,14 @@ class security_manager {
         }
         
         // Check if IP is blocked
-        $stmt = $this->db->prepare('SELECT * FROM blocked_ips WHERE ip_address = :ip AND (unblock_time > :time OR unblock_time = 0)');
+        $stmt = $this->db->prepare('SELECT * FROM blocked_ips WHERE ip_address = :ip AND (unblock_time > :time OR unblock_time = -1)');
         $stmt->bindValue(':ip', $ip_address, SQLITE3_TEXT);
         $stmt->bindValue(':time', time(), SQLITE3_INTEGER);
         $result = $stmt->execute();
         $row = $result->fetchArray(SQLITE3_ASSOC);
         
         if ($row) {
-            // Auto-unblock if time has expired (but not for indefinite blocks with unblock_time = 0)
+            // Auto-unblock if time has expired (but not for permanent blocks with unblock_time = -1)
             if ($row['unblock_time'] > 0 && $row['unblock_time'] <= time()) {
                 $this->unblock_ip($ip_address);
                 return false;
@@ -397,7 +397,7 @@ class security_manager {
     }
     
     public function get_blocked_ips() {
-        $stmt = $this->db->prepare('SELECT * FROM blocked_ips WHERE unblock_time > :time OR unblock_time = 0 ORDER BY block_time DESC');
+        $stmt = $this->db->prepare('SELECT * FROM blocked_ips WHERE unblock_time > :time OR unblock_time = -1 ORDER BY block_time DESC');
         $stmt->bindValue(':time', time(), SQLITE3_INTEGER);
         $result = $stmt->execute();
         
@@ -492,8 +492,8 @@ class security_manager {
     }
     
     public function get_security_stats() {
-        // Get current blocked IPs count (including indefinite blocks)
-        $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM blocked_ips WHERE unblock_time > :time OR unblock_time = 0');
+        // Get current blocked IPs count (including permanent blocks)
+        $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM blocked_ips WHERE unblock_time > :time OR unblock_time = -1');
         $stmt->bindValue(':time', time(), SQLITE3_INTEGER);
         $result = $stmt->execute();
         $blocked_count = $result->fetchArray(SQLITE3_ASSOC)['count'];
