@@ -1,7 +1,7 @@
 <?php
 // Permission checking is now handled by the permission system in auto-prepend.php
 // 
-// NS Record Fix (2024): Domains now properly create 2 NS records instead of 1
+// NS Record Fix (2025): Domains now properly create 2 NS records instead of 1
 // - Fixed addDefaultRecords() to add all NS records in single API call
 // - PowerDNS API uses 'changetype' => 'REPLACE' which was overwriting previous NS records
 // - Solution: Collect all nameservers and add them together via addMultipleRecords()
@@ -364,6 +364,15 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                             break;
                         }
                         
+                        // Auto-quote TXT records if not already quoted
+                        if ($record_type === 'TXT') {
+                            // Check if the content is not already quoted
+                            if (!preg_match('/^".*"$/', $record_content)) {
+                                // Add quotes around the content
+                                $record_content = '"' . $record_content . '"';
+                            }
+                        }
+                        
                         // Check domain ownership
                         $stmt = $db->prepare("SELECT username FROM whp.domains WHERE domain_name = ?");
                         $stmt->execute([$domain_name]);
@@ -476,6 +485,15 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                             break;
                         }
                         
+                        // Auto-quote TXT records if not already quoted
+                        if ($record_type === 'TXT') {
+                            // Check if the content is not already quoted
+                            if (!preg_match('/^".*"$/', $record_content)) {
+                                // Add quotes around the content
+                                $record_content = '"' . $record_content . '"';
+                            }
+                        }
+                        
                         // Check domain ownership
                         $stmt = $db->prepare("SELECT username FROM whp.domains WHERE domain_name = ?");
                         $stmt->execute([$domain_name]);
